@@ -1,9 +1,10 @@
+# shellcheck shell=bash
 # no need for shebang - this file is loaded from charts.d.plugin
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 # netdata
 # real-time performance and health monitoring, done right!
 # (C) 2016 Costa Tsaousis <costa@tsaousis.gr>
-# GPL v3+
 #
 # Contributed by @jsveiga with PR #480
 
@@ -22,7 +23,7 @@ exim_check() {
         exim_command="${EXIM_CMD}"
     fi
 
-	if [ $(${exim_command} -bpc 2>&1 | grep -c denied) -ne 0 ]
+	if [ "$(${exim_command} -bpc 2>&1 | grep -c denied)" -ne 0 ]
 	then
 		error "permission denied - please set 'queue_list_requires_admin = false' in your exim options file"
 		return 1
@@ -41,7 +42,7 @@ EOF
 
 exim_update() {
     echo "BEGIN exim_local.qemails $1"
-    echo "SET emails = " $(run ${exim_command} -bpc)
+    echo "SET emails = $(run "${exim_command}" -bpc)"
     echo "END"
     return 0
 }
